@@ -1,6 +1,5 @@
-from django.template import Library, Node, Variable
+from django.template import Library, Node, Variable, VariableDoesNotExist
 from django.template.loader import get_template
-from copy import copy
 
 
 register = Library()
@@ -15,16 +14,19 @@ class AdrestInclusionNode(Node):
         super(AdrestInclusionNode, self).__init__()
 
     def render(self, context):
-        target = self.var.resolve(context)
-        if not target:
+        try:
+            target = self.var.resolve(context)
+            assert target
+        except (VariableDoesNotExist, AssertionError):
             return ''
 
         emitter = context.get('emitter')
         t_name = emitter.get_template_path(target)
         t = get_template(t_name)
-        context = copy(context)
-        context['content'] = target
-        return t.nodelist.render(context)
+        context.dicts.append(dict(content=target))
+        response = t.nodelist.render(context)
+        context.pop()
+        return response
 
 
 def adrest_include(parser, token):
